@@ -8,7 +8,7 @@ use Time::Local qw//;
 use POSIX qw//;
 use base qw/Exporter/;
 
-our $VERSION = "0.12";
+our $VERSION = "0.13";
 our @EXPORT_OK = qw/strftime/;
 
 use constant {
@@ -250,7 +250,7 @@ our %LOCALE_CHARS = (
     'Z' => [q!'%Z'!,1],
 );
 
-if ( $^O eq 'MSWin32' || $^O eq 'Cygwin' ) {
+if ( $^O =~ m!^(MSWin32|cygwin)$!i ) {
     %LOCALE_CHARS = (
         %LOCALE_CHARS,
         'D' => [q!'%m/%d/%y'!],
